"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const IpfsTransportProvider_1 = require("./Ipfs/IpfsTransportProvider");
const WebSocketTransportProvider_1 = require("./ws/WebSocketTransportProvider");
const DirectTransportProvider_1 = require("./direct/DirectTransportProvider");
const dc_configs_1 = require("dc-configs");
class TransportProviderFactory {
    constructor(type = dc_configs_1.config.default.transport) {
        // console.log(typeof type)
        if (type)
            this.setType(type);
    }
    setType(type) {
        this._type = type;
    }
    toString() {
        return dc_configs_1.TransportType[this._type];
    }
    getType() {
        return this._type;
    }
    create() {
        switch (this._type) {
            case dc_configs_1.TransportType.IPFS:
                return IpfsTransportProvider_1.IpfsTransportProvider.create();
            case dc_configs_1.TransportType.WS:
                return WebSocketTransportProvider_1.WebSocketTransportProvider.create();
            case dc_configs_1.TransportType.DIRECT:
                return DirectTransportProvider_1.DirectTransportProvider.create();
        }
        throw new Error("Selected type doesn't exists");
    }
}
exports.TransportProviderFactory = TransportProviderFactory;
//# sourceMappingURL=TransportProviderFactory.js.map